# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_project.ipynb.

# %% auto #0
__all__ = ['OVHProject']

# %% ../nbs/01_project.ipynb #46c7d6f2-2b91-4559-9cf8-bc2e807febd6
class OVHProject():
    def __init__(self, id:str, region:str=None, consumption_mode:str=None):
        """
        OVH Project class, storing project information

        Parameters
        ----------
        id : str, required
            OVH project id
        region : str, optional
            Project ressources region
        """
        self.id = id
        self.base_url = f'/cloud/project/{self.id}'
        self.region = None

    def set_region(self, region:str):
        """
        Sets the project's region

        Parameters
        ----------
        region : str, required
            Project ressources region
        """
        self.region = region




# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_catalog.ipynb.

# %% auto #0
__all__ = ['GPUCatalog']

# %% ../nbs/02_catalog.ipynb #82b62621-7175-4ae2-a472-d373d761c3ef
from loguru import logger
from tabulate import tabulate


# %% ../nbs/02_catalog.ipynb #edd58877-acd6-47ae-b904-622a45646aad
class GPUCatalog():
    def __init__(self, catalog_dict:dict, region:str, subsidiary:str='FR'):
        """
        OVH Project class, storing project information
    
        Parameters
        ----------
        catalog_dict : dict, required
            OVH Catalog dictionary
        region : str, required
            OVH Catalog region
        subsidiary : str, required
            OVH Catalog subsidiary/country, default set to FR (France)
        consumption_mode: str, required
            OVH Ressource consumption mode, default set to consumption. Possible values ['consumption', 'monthly.postpaid']
        """
        self.region = region
        self.subsidiary = subsidiary
        self.catalog_dict = catalog_dict
        self.consumption_mode = None
        self.gpu_families =  ['a10', 'rtx5000', 't1', 't2', 'l4', 'h100']
        self.ressource_type = 'instance'
        self._project_plans = []
        self._instances_addons = []
        self._gpu_addons = []
        self.gpu_instances_data = []

    def _list_project_plans(self):
        """
        Lists OVH Catalog Plans
        """ 
        self._project_plans = [p for p in self.catalog_dict['plans'] if (p['planCode']=='project' and p['invoiceName']=='Public Cloud Project')]

    def _list_addons(self):
        """
        Lists OVH Plans addons
        """ 
        self._instances_addons = [p for p in self._project_plans[0]['addonFamilies'] if p['name']==self.ressource_type]

    def _list_gpu_addons(self, consumption_mode:str='consumption'):
        """
        Lists OVH GPU Addons
        """ 
        dict_consumption_mode = {
            'consumption': 'consumption',
            'monthly.postpaid': 'monthly'
        }
        self._gpu_addons = [i for i in self._instances_addons[0]['addons'] 
                           if (i.split('.')[0].split('-')[0] in self.gpu_families) 
                           and (dict_consumption_mode.get(consumption_mode) in i.split('.')[1])]

    def list_gpu_instances(self, consumption_mode:str='consumption'):
        """
        Lists available gpu instances for the OVH Catalog. It displays a table containing:
        - Name
        - Price (hourly or monthly depending on consumption mode)
        - GPU Model
        - GPU Memory
        - CPU Cores
        - RAM

        Parameters
        ----------
        consumption_mode : str, required, default to consumption (consumption or monthly.postpaid) 
            GPU instance consumption mode
        """
        self._list_project_plans()
        self._list_addons()
        self._list_gpu_addons(consumption_mode)

        dict_consumption_mode = {
            'consumption': 'per hour',
            'monthly.postpaid': 'per month'
        }
        
        self.gpu_instances_data = []
        for addon_code in sorted(self._gpu_addons):
            addon = [p for p in self.catalog_dict['addons'] if p['planCode'] == addon_code]
            if addon:
                a = addon[0]
                self.gpu_instances_data.append({
                    'Name': a['invoiceName'],
                    f'Price {dict_consumption_mode.get(consumption_mode)}': a['pricings'][0]['formattedPrice'],
                    'GPU Model': a['blobs']['technical']['gpu']['model'],
                    'GPU Memory': f"{a['blobs']['technical']['gpu']['memory']['size']}GB",
                    'CPU Cores': a['blobs']['technical']['cpu']['cores'],
                    'RAM': f"{a['blobs']['technical']['memory']['size']}GB"
                })
    
        logger.info("Available GPU instances:")
        print(tabulate(self.gpu_instances_data, headers='keys', tablefmt='grid', showindex=range(1, len(self.gpu_instances_data)+1)))    
        



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto #0
__all__ = ['OVHGPUManager']

# %% ../nbs/00_core.ipynb #48db86d2-8f14-4a81-a6b4-4b5ecae5eaed
import ovh
from fastcore.basics import patch
from loguru import logger
from typing import Any

# Simple, direct imports - let Python handle the module resolution
try:
    from ovhmanager.project import OVHProject
    from ovhmanager.catalog import GPUCatalog
    from ovhmanager.instance import GPUInstance
except ImportError:
    # Fallback for development/notebook environment
    from .project import OVHProject
    from .catalog import GPUCatalog
    from .instance import GPUInstance

# %% ../nbs/00_core.ipynb #851196c9-23bf-47da-9b36-c78d9cccdce8
class OVHGPUManager:
    def __init__(self, endpoint=None, application_key=None, application_secret=None, consumer_key=None):
        """
        OVHGPUManager is a OVH API client wrapper that enables to create, delete, start and stop GPU instances
        
        By default the OVH client expects the following environment variables to be set, but you can overwrite them using the provided arguments:
        - OVH_ENDPOINT
        - OVH_APPLICATION_KEY
        - OVH_APPLICATION_SECRET
        - OVH_CONSUMER_KEY

        Parameters
        ----------
        endpoint : str, optional
            API endpoint like 'ovh-eu'
        application_key : str, optional
            Application key
        application_secret : str, optional
            Application secret
        consumer_key : str, optional
            Consumer key
        """
        self.client = ovh.Client(
        endpoint=endpoint,
        application_key=application_key,
        application_secret=application_secret,
        consumer_key=consumer_key)

        self._base_catalog_url = "/order/catalog/public/cloud"
        self.region = None
        self.project = None
        self.consumption_mode = None
        self.catalog_dict = None
        self.catalog = None
        self.gpu_type = None
        self.gpu_flavor_id = None
        self.instance_image_id = None
        self.instance_image_name = None
        self.ssh_key_id = None
        self.ssh_key_name = None
        self.last_gpu_instance = None
        self.last_instance_dict = None
        self.gpu_instances = []

# %% ../nbs/00_core.ipynb #0255805d-b5c4-4601-90dc-0b8ba5010a8d
@patch
def list_projects(self:OVHGPUManager)->list:
    """
    Returns the list of available project IDs for the OVH Cloud account
    """
    return self.client.get('/cloud/project')

# %% ../nbs/00_core.ipynb #5bf0afe2-ace5-44bc-adc0-a44883c943f9
@patch
def select_project(self:OVHGPUManager, project_idx:str=None)->Any:
    """
    Lists available projects for the OVH Cloud account and prompts user to select a project if no project id is passed as an argument
    
    Parameters
    ----------
    project_idx : str, optional
        Project OVH ID
    """
    logger.info("Available projects:")
    projects = self.list_projects()
    for i, p in enumerate(projects):
        print(f"{i+1}. {p}")
    if not project_idx:
        idx = int(input("Select project number: ")) - 1
        project_idx = projects[idx]
    self.project = OVHProject(project_idx)
    logger.info(f"Selected project: {self.project.id}")
    return self.project

# %% ../nbs/00_core.ipynb #00e6bfde-8a00-4a07-bd83-22bc3be5621f
@patch
def list_regions(self:OVHGPUManager)->list:
    """
    Returns the list region for the selected project
    """
    return self.client.get(f'{self.project.base_url}/region')
    

# %% ../nbs/00_core.ipynb #19cdd001-ac26-4637-97f8-ef0d5064991d
@patch
def select_region(self:OVHGPUManager, region:str=None)->Any:
    """
    Lists available region for the OVH Project and prompts user to select a region if no region is passed as an argument
    This method sets both the OVHGPUManager and the OVHProject
    
    Parameters
    ----------
    region : str, optional
        OVH region
    """
    if not region:
        logger.info("Available region:")
        regions = self.list_regions()
        for i, p in enumerate(regions):
            print(f"{i+1}. {p}")
        idx = int(input("Select region number: ")) - 1
        region = regions[idx]
    self.region = (region)
    if self.project:
        self.project.set_region(self.region)
    logger.info(f"Selected region: {self.region}")
    return self.region

# %% ../nbs/00_core.ipynb #6d8b8b3d
@patch
def select_consumption_mode(self:OVHGPUManager, consumption_mode:str=None)->str:
    """
    Lists available OVH ressources consumption modes and prompts user to select a consumption mode if no mode is passed as an argument

    Parameters
    ----------
    consumption_mode : str, optional
        Ressource consumption mode
    """
    if not consumption_mode:
        logger.info("Available consumption modes:")
        print("\nConsumption modes:")
        print("1. consumption (hourly)")
        print("2. monthly.postpaid")
        mode_choice = int(input("Select mode: "))
        consumption_mode = 'consumption' if mode_choice == 1 else 'monthly.postpaid'
    self.consumption_mode = consumption_mode
    logger.info(f"Selected consumption mode: {self.consumption_mode}")
    return self.consumption_mode

# %% ../nbs/00_core.ipynb #33167b7d-451f-4c34-8c9a-b63273af3c2d
@patch
def retrieve_catalog_dict(self:OVHGPUManager, subsidiary='FR') ->dict:
    """
    Retrieves an OVH catalog for a specific OVH subsidiary

    Parameters
    ----------
    subsidiary : str, required, defaults to FR
        OVH catalpg subsidiary/country code
    """
    self.catalog_dict = self.client.get(f'{self._base_catalog_url}', ovhSubsidiary=subsidiary, region=self.region)
    logger.info(f"Retrieved catalog dictionary for {subsidiary} subsidiary")

    return self.catalog_dict
    

# %% ../nbs/00_core.ipynb #5043d3b2-1fa2-45da-b149-03cb7cb793d3
@patch
def select_gpu_instance_type(self:OVHGPUManager, subsidiary='FR', gpu_type=None, consumption_mode=None)->Any:
    """
    Lists available OVH GPU instance types and prompts user to select a GPU type if no gpu type is passed as an argument

    Parameters
    ----------
    subsidiary : str, required, defaults to FR
        OVH catalog subsidiary/country code
    gpu_type : str, optional
        GPU instance type
    consumption_mode : str, optional
        Ressource consumption mode
    """
    # 0. make sure region and projects are set
    if not self.project:
        self.select_project()
    if not self.region:
        self.select_region()
    
    # 1. retrieve the catalog for subsidiary and region combination
    self.retrieve_catalog_dict()
    self.catalog = GPUCatalog(self.catalog_dict, self.region, subsidiary)
    logger.info(f"Retrieved OVH catalog")

    # 2. select consumption mode
    self.select_consumption_mode(consumption_mode)

    if not gpu_type:
        # 3. list available gpu types for 
        self.catalog.list_gpu_instances(self.consumption_mode)
    
        # 4. select gpu instance type
        gpu_idx = int(input("\nSelect GPU instance number: ")) - 1
        gpu_type = self.catalog.gpu_instances_data[gpu_idx]['Name']
        
    self.gpu_type = gpu_type
    logger.info(f"Selected GPU: {self.gpu_type}, with {self.consumption_mode} consumption mode")
    return self.gpu_type

# %% ../nbs/00_core.ipynb #6a22ad75-0b0e-441c-aee3-976ec595e3a0
@patch
def retrieve_gpu_flavor(self:OVHGPUManager)->str:
    """
    Retrieve the OVH instance flavor associated the selected GPU type
    """
    try:
        flavors = self.client.get(f'{self.project.base_url}/flavor', region=self.region)
    except Exception:
        print(f'Cannot find ressources for {self.region} region. Please select another region')
        return None
    
    flavor = [f for f in flavors if f['name'] == self.gpu_type][0]
    self.gpu_flavor_id = flavor['id']
    logger.info(f"Selected GPU flavor id: {self.gpu_flavor_id}")
    return self.gpu_flavor_id

# %% ../nbs/00_core.ipynb #43d75cdd-f18b-4cbb-925a-5ccda77089a2
@patch
def select_instance_image(self:OVHGPUManager, image_family:str='Ubuntu', image_id:str=None, image_name:str=None)->tuple:
    """
    Lists available instance images and prompts user to select an image if no image ID an is passed as an argument

    Parameters
    ----------
    image_family : str, required, defaults to Ubuntu
        The OS familly to look for. Based on key word search
    image_id : str, optional
        The image id if already nown
    image_name : str, optional
        The image name if already nown
    """
    images = self.client.get(f'{self.project.base_url}/image', region=self.region)
    ubuntu_images = [img for img in images if image_family in img['name']]
    if (not image_id) and (not image_name):
        logger.info("\nAvailable Ubuntu images:")
        for i, img in enumerate(ubuntu_images):
            print(f"{i+1}. {img['name']}")
        image_idx = int(input("Select image number: ")) - 1
        selected_image = ubuntu_images[image_idx]
        image_id = selected_image['id']
        image_name = selected_image['name']
    self.instance_image_id = image_id
    self.instance_image_name = image_name
    logger.info(f"Selected instance image: {self.instance_image_id}:{self.instance_image_name}")
    return self.instance_image_id, self.instance_image_name

# %% ../nbs/00_core.ipynb #06b957a8-a0b8-4d37-a1e3-72a100f5b5b9
@patch
def select_ssh_key(self:OVHGPUManager, ssh_key_id:str=None, ssh_key_name:str=None)->tuple:
    """
    Lists available ssh keys and prompts user to select a ssh key if no ssh key ID is passed as an argument

    Parameters
    ----------
    ssh_key_id : str, optional
        OVH ssh key ID
    ssh_key_name: str, optional
        OVH ssh key name
    """
    ssh_keys = self.client.get(f'{self.project.base_url}/sshkey', region=self.region)
    if not ssh_key_id:
        logger.info("\nAvailable SSH keys:")
        for i, key in enumerate(ssh_keys):
            print(f"{i+1}. {key['name']}")
        ssh_idx = int(input("Select SSH key number: ")) - 1
        ssh_key_id = ssh_keys[ssh_idx]['id']
        ssh_key_name = ssh_keys[ssh_idx]['name']
    self.ssh_key_id = ssh_key_id
    self.ssh_key_name =ssh_key_name
    logger.info(f"Selected SSH key: {self.ssh_key_id}:{self.ssh_key_name}")
    return self.ssh_key_id, self.ssh_key_name

# %% ../nbs/00_core.ipynb #f9a187e4-19db-4e61-bcb3-c098cd0e6cb1
@patch
def create_instance(self:OVHGPUManager, subsidiary='FR', gpu_type=None, consumption_mode=None, image_family:str='Ubuntu',
                    image_id:str=None, image_name:str=None, ssh_key_id:str=None, ssh_key_name:str=None, instance_name=None)->Any:

    """
    Creates an OVH GPU instance either using passed arguments otherwise by prompting the user for inputs

    Parameters
    ----------
    subsidiary : str, required, defaults to FR
        OVH catalpg subsidiary/country code
    gpu_type : str, optional
        GPU instance type
    consumption_mode : str, optional
        Ressource consumption mode
    image_family : str, required, defaults to Ubuntu
        The OS familly to look for. Based on key word search
    image_id : str, optional
        The image id if already nown
    image_name : str, optional
        The image name if already nown
    ssh_key_id : str, optional
        OVH ssh key ID
    ssh_key_name: str, optional
        OVH ssh key name
    instance_name: str, optional
        OVH instance name
    """
    
    self.select_gpu_instance_type(subsidiary, gpu_type, consumption_mode)    
    self.retrieve_gpu_flavor()
    self.select_instance_image(image_family, image_id, image_name)
    self.select_ssh_key(ssh_key_id, ssh_key_name)

    if not instance_name:
        instance_name = input("\nEnter instance name: ")
    self.instance_name = instance_name
    logger.info(f"\nCreating instance '{self.instance_name}'...")
    
    # 5. create instance
    self.last_instance_dict = self.client.post(f'{self.project.base_url}/instance', 
        flavorId=self.gpu_flavor_id,
        imageId=self.instance_image_id,
        name=self.instance_name,
        region=self.region,
        sshKeyId=self.ssh_key_id
    )
    self.last_gpu_instance = GPUInstance(
        client=self.client,
        project_base_url=self.project.base_url,
        region=self.region,
        name=self.last_instance_dict.get('name', 'No Name'),
        status=self.last_instance_dict.get('status', 'No Status'),
        id=self.last_instance_dict.get('id', 'XXXX'),
        gpu_type=self.gpu_type,
        flavor_id=self.gpu_flavor_id,
        image_id=self.instance_image_id,
        consumption_mode=self.consumption_mode,
        created=self.last_instance_dict.get('created', 'No Date')
    )
    return self.last_gpu_instance, self.last_instance_dict

# %% ../nbs/00_core.ipynb #3983ba08-51ba-44a3-9124-b2828a1464f7
@patch
def list_instances(self:OVHGPUManager)->list:
    """
    Lists and displays available OVH GPU instances for specific project
    """
    instances = self.client.get(f'{self.project.base_url}/instance')
    self.gpu_instances = []
    logger.info('\nAvailable GPU instances:')
    for i in instances:
        gpu_type = i.get('planCode').split('.')[0]
        consumption_mode = '.'.join(i.get('planCode').split('.')[1:])
        instance = GPUInstance(
            client=self.client,
            project_base_url=self.project.base_url,
            region=i.get('region'),
            name=i.get('name'),
            status=i.get('status'),
            id=i.get('id'),
            gpu_type=gpu_type,
            flavor_id=i.get('flavorId'),
            image_id=i.get('imageId'),
            consumption_mode=consumption_mode,
            created=i.get('created')
            )
        instance.display_details()
        print(f'------\n')
        self.gpu_instances.append(instance)
        
    return self.gpu_instances

# %% ../nbs/00_core.ipynb #1d6d3367-ba57-41fe-909f-62a909f0d821
@patch
def get_instance(self:OVHGPUManager, instance_id:str)->tuple:
    """
    Retrieves an OVH GPU instance information for a specific instance ID

    Parameters
    ----------
    instance_id : str, required
        OVH GPU instance id
    """
    self.last_instance_dict = self.client.get(f'{self.project.base_url}/instance/{instance_id}')
    if self.last_instance_dict:
        gpu_type = None
        consumption_mode = None
        if self.last_instance_dict.get('planCode'):
            gpu_type = self.last_instance_dict.get('planCode').split('.')[0]
            consumption_mode = '.'.join(self.last_instance_dict.get('planCode').split('.')[1:])
        self.last_gpu_instance = GPUInstance(
                client=self.client,
                project_base_url=self.project.base_url,
                region=self.last_instance_dict.get('region'),
                name=self.last_instance_dict.get('name'),
                status=self.last_instance_dict.get('status'),
                id=self.last_instance_dict.get('id'),
                gpu_type=gpu_type,
                flavor_id=self.last_instance_dict.get('flavor')['id'] if self.last_instance_dict.get('flavor') else None,
                image_id=self.last_instance_dict.get('image')['id'] if self.last_instance_dict.get('image') else None,
                consumption_mode=consumption_mode,
                created=self.last_instance_dict.get('created')
                )
        self.last_gpu_instance.display_details()
    return self.last_gpu_instance ,self.last_instance_dict



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/ovhmanager',
                'doc_host': 'https://hassoun.github.io',
                'git_url': 'https://github.com/hassoun/ovhmanager',
                'lib_path': 'ovhmanager'},
  'syms': { 'ovhmanager.catalog': { 'ovhmanager.catalog.GPUCatalog': ('catalog.html#gpucatalog', 'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog.__init__': ('catalog.html#gpucatalog.__init__', 'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog._list_addons': ( 'catalog.html#gpucatalog._list_addons',
                                                                                    'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog._list_gpu_addons': ( 'catalog.html#gpucatalog._list_gpu_addons',
                                                                                        'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog._list_project_plans': ( 'catalog.html#gpucatalog._list_project_plans',
                                                                                           'ovhmanager/catalog.py'),
                                    'ovhmanager.catalog.GPUCatalog.list_gpu_instances': ( 'catalog.html#gpucatalog.list_gpu_instances',
                                                                                          'ovhmanager/catalog.py')},
            'ovhmanager.core': { 'ovhmanager.core.OVHGPUManager': ('core.html#ovhgpumanager', 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.__init__': ('core.html#ovhgpumanager.__init__', 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.create_instance': ( 'core.html#ovhgpumanager.create_instance',
                                                                                    'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.get_instance': ( 'core.html#ovhgpumanager.get_instance',
                                                                                 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.list_instances': ( 'core.html#ovhgpumanager.list_instances',
                                                                                   'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.list_projects': ( 'core.html#ovhgpumanager.list_projects',
                                                                                  'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.list_regions': ( 'core.html#ovhgpumanager.list_regions',
                                                                                 'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.retrieve_catalog_dict': ( 'core.html#ovhgpumanager.retrieve_catalog_dict',
                                                                                          'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.retrieve_gpu_flavor': ( 'core.html#ovhgpumanager.retrieve_gpu_flavor',
                                                                                        'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_consumption_mode': ( 'core.html#ovhgpumanager.select_consumption_mode',
                                                                                            'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_gpu_instance_type': ( 'core.html#ovhgpumanager.select_gpu_instance_type',
                                                                                             'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_instance_image': ( 'core.html#ovhgpumanager.select_instance_image',
                                                                                          'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_project': ( 'core.html#ovhgpumanager.select_project',
                                                                                   'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_region': ( 'core.html#ovhgpumanager.select_region',
                                                                                  'ovhmanager/core.py'),
                                 'ovhmanager.core.OVHGPUManager.select_ssh_key': ( 'core.html#ovhgpumanager.select_ssh_key',
                                                                                   'ovhmanager/core.py')},
            'ovhmanager.instance': { 'ovhmanager.instance.GPUInstance': ('instance.html#gpuinstance', 'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.__init__': ( 'instance.html#gpuinstance.__init__',
                                                                                   'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.delete': ( 'instance.html#gpuinstance.delete',
                                                                                 'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.display_details': ( 'instance.html#gpuinstance.display_details',
                                                                                          'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.start': ('instance.html#gpuinstance.start', 'ovhmanager/instance.py'),
                                     'ovhmanager.instance.GPUInstance.stop': ('instance.html#gpuinstance.stop', 'ovhmanager/instance.py')},
            'ovhmanager.project': { 'ovhmanager.project.OVHProject': ('project.html#ovhproject', 'ovhmanager/project.py'),
                                    'ovhmanager.project.OVHProject.__init__': ('project.html#ovhproject.__init__', 'ovhmanager/project.py'),
                                    'ovhmanager.project.OVHProject.set_region': ( 'project.html#ovhproject.set_region',
                                                                                  'ovhmanager/project.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_instance.ipynb.

# %% auto #0
__all__ = ['GPUInstance']

# %% ../nbs/03_instance.ipynb #43bfb04b-d169-4901-8e76-07c4cb4a386d
from loguru import logger
import ovh
from fastcore.basics import patch

# %% ../nbs/03_instance.ipynb #49ee9208-6677-402f-a029-02a224c27cab
class GPUInstance():
    def __init__(self, client:ovh.client, project_base_url:str, region:str, name:str, id:str, status:str, gpu_type:str, flavor_id:str, image_id:str, consumption_mode:str, created:str):
        """
        OVH GPU Instance class, enabling to interact with the instance (start/stop/delete)
    
        Parameters
        ----------
        client: ovh.client, required
            OVH client
        project_base_url: str, required
            OVH project base url
        region : str, required
            OVH GPU Instance region
        name : str, required
            OVH GPU Instance name
        id : str, required
            OVH GPU Instance id
        status : str, required
            OVH GPU Instance status
        gpu_type : str, required
            OVH GPU Instance gpu_type
        flavor_id : str, required
            OVH GPU Instance flavor_id
        image_id : str, required
            OVH GPU Instance image_id
        consumption_type : str, required
            OVH GPU Instance consumption mode
        created : str, required
            OVH GPU Instance creation date
        """
        self.client = client
        self.project_base_url = project_base_url
        self.region = region
        self.name = name
        self.id = id
        self.status = status
        self.gpu_type = gpu_type
        self.flavor_id = flavor_id
        self.image_id = image_id
        self.consumption_mode = consumption_mode
        self.planCode = f'{gpu_type}.{consumption_mode}'
        self.created = created

    def display_details(self):
        """Display all instance attributes"""
        for key, value in self.__dict__.items():
            print(f"{key}: {value}")

# %% ../nbs/03_instance.ipynb #3966a669-90cf-464d-bb22-f570897280c3
@patch
def delete(self:GPUInstance):
    """
    Enables an OVH GPU instance to delete it's self
    
    Parameters
    ----------
    instance_id: str, required
        OVH instance ID
    """
    logger.info(f"\n Deleting instance")
    self.client.delete(f'{self.project_base_url}/instance/{self.id}')
    self.status = 'DELETED'
    logger.info(f"\n GPU Instance: {self.id} is being deleted")
    return None

# %% ../nbs/03_instance.ipynb #c0cdc947-ac84-47f7-8c15-e03af1aaa5ce
@patch
def start(self:GPUInstance):
    """
    Enables an OVH GPU instance to start it's self
    
    Parameters
    ----------
    instance_id: str, required
        OVH instance ID
    """
    logger.info(f"\n Starting instance")
    self.client.post(f'{self.project_base_url}/instance/{self.id}/start')
    self.status='ACTIVE'
    logger.info(f"\n GPU Instance: {self.id} is being started")
    return None

# %% ../nbs/03_instance.ipynb #38e5357b-510d-4f66-a054-7e888dd84d14
@patch
def stop(self:GPUInstance):
    """
    Enables an OVH GPU instance to start it's self
    
    Parameters
    ----------
    instance_id: str, required
        OVH instance ID
    """
    logger.info(f"\n Stopping instance")
    self.client.post(f'{self.project_base_url}/instance/{self.id}/stop')
    self.status='SHUTOFF'
    logger.info(f"\n GPU Instance: {self.id} is being stopped")
    return None
